==> openshift-model-operator-5.1.1-sources.jar: annotations/io/fabric8/openshift/api/model/operator/v1/HybridOverlayConfigBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class HybridOverlayConfigBuilder extends HybridOverlayConfigFluentImpl<HybridOverlayConfigBuilder> implements VisitableBuilder<HybridOverlayConfig,HybridOverlayConfigBuilder> {

    HybridOverlayConfigFluent<?> fluent;
    Boolean validationEnabled;

    public HybridOverlayConfigBuilder() {
        this(true);
    }

    public HybridOverlayConfigBuilder(Boolean validationEnabled) {
        this(new HybridOverlayConfig(), validationEnabled);
    }

    public HybridOverlayConfigBuilder(HybridOverlayConfigFluent<?> fluent) {
        this(fluent, true);
    }

    public HybridOverlayConfigBuilder(HybridOverlayConfigFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new HybridOverlayConfig(), validationEnabled);
    }

    public HybridOverlayConfigBuilder(HybridOverlayConfigFluent<?> fluent,HybridOverlayConfig instance) {
        this(fluent, instance, true);
    }

    public HybridOverlayConfigBuilder(HybridOverlayConfigFluent<?> fluent,HybridOverlayConfig instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withHybridClusterNetwork(instance.getHybridClusterNetwork()); 
        fluent.withHybridOverlayVXLANPort(instance.getHybridOverlayVXLANPort()); 
        this.validationEnabled = validationEnabled; 
    }

    public HybridOverlayConfigBuilder(HybridOverlayConfig instance) {
        this(instance,true);
    }

    public HybridOverlayConfigBuilder(HybridOverlayConfig instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withHybridClusterNetwork(instance.getHybridClusterNetwork()); 
        this.withHybridOverlayVXLANPort(instance.getHybridOverlayVXLANPort()); 
        this.validationEnabled = validationEnabled; 
    }

    public HybridOverlayConfig build() {
        HybridOverlayConfig buildable = new HybridOverlayConfig(fluent.getHybridClusterNetwork(),fluent.getHybridOverlayVXLANPort());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        HybridOverlayConfigBuilder that = (HybridOverlayConfigBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> openshift-model-operator-5.3.1-sources.jar: annotations/io/fabric8/openshift/api/model/operator/v1/HybridOverlayConfigBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class HybridOverlayConfigBuilder extends HybridOverlayConfigFluentImpl<HybridOverlayConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<HybridOverlayConfig,HybridOverlayConfigBuilder> {

    HybridOverlayConfigFluent<?> fluent;
    Boolean validationEnabled;

    public HybridOverlayConfigBuilder() {
        this(true);
    }

    public HybridOverlayConfigBuilder(Boolean validationEnabled) {
        this(new HybridOverlayConfig(), validationEnabled);
    }

    public HybridOverlayConfigBuilder(HybridOverlayConfigFluent<?> fluent) {
        this(fluent, true);
    }

    public HybridOverlayConfigBuilder(HybridOverlayConfigFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new HybridOverlayConfig(), validationEnabled);
    }

    public HybridOverlayConfigBuilder(HybridOverlayConfigFluent<?> fluent,HybridOverlayConfig instance) {
        this(fluent, instance, true);
    }

    public HybridOverlayConfigBuilder(HybridOverlayConfigFluent<?> fluent,HybridOverlayConfig instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withHybridClusterNetwork(instance.getHybridClusterNetwork()); 
        fluent.withHybridOverlayVXLANPort(instance.getHybridOverlayVXLANPort()); 
        this.validationEnabled = validationEnabled; 
    }

    public HybridOverlayConfigBuilder(HybridOverlayConfig instance) {
        this(instance,true);
    }

    public HybridOverlayConfigBuilder(HybridOverlayConfig instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withHybridClusterNetwork(instance.getHybridClusterNetwork()); 
        this.withHybridOverlayVXLANPort(instance.getHybridOverlayVXLANPort()); 
        this.validationEnabled = validationEnabled; 
    }

    public HybridOverlayConfig build() {
        HybridOverlayConfig buildable = new HybridOverlayConfig(fluent.getHybridClusterNetwork(),fluent.getHybridOverlayVXLANPort());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        HybridOverlayConfigBuilder that = (HybridOverlayConfigBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
